<?php
if (!class_exists('WPContentMagic_ClicksLinks')) {
	class WPContentMagic_ClicksLinks
	{
		/**
		 * Table to save it in database
		 * @var string
		 */
		private $db_table;
		
		/**
		 * Create object
		 * 
		 * @param int 	$id
		 * @param array $settings
		 */
		public function __construct() {
			$this->set_db_table();
		}
		
		/**
		 * @return the $db_table
		 */
		public function get_db_table() {
			return $this->db_table;
		}

		/**
		 * @param $db_table the $db_table to set
		 */
		public function set_db_table() {
			global $wpdb;
		   	$db_table =  $wpdb->prefix . WPContentMagic::$db_prefix . 'clicks_links';
		   	
			$this->db_table = $db_table;
		}
		
		/**
		 * Get the common query to perform when the list or the count is requested
		 * 
		 * @param	string	$link
		 * @param	int		$clicks_how_many
		 * @param	int		$ip_from_how_many
		 * 
		 * @param	string	$not_condition		if 1, will be applied a NOT to the conditions of the query
		 * 
		 * 
		 * @return 	array	first element is the Query, second is the array with the values for the placeholders in query
		 */
		private function get_common_query($link='',$clicks_how_many='',$ip_from_how_many=''
										,$not_condition=0) {
		
			$table = $this->get_db_table();
			
			// Initialize query, Set all fields to return
			$query = "select * from (
				select `id`,`link`, count( `id` ) as clicks_how_many, count( DISTINCT `ip_from` ) as ip_from_how_many";
			
			// From and inner joins
			$query .= " from $table";
			
			// Add group by
			$query .= ' group by `link`) `clicks_new_table`';
			
			$query_params = array();
			
			// Where conditions
			$where_conditions = array();
										
			if ($link!='') {
				$where_conditions[] = " `link` like %s";
				$query_params[] = "%$link%";
			}
			if ($clicks_how_many!='' && $clicks_how_many!='0') {
				$where_conditions[] = " clicks_how_many = %d";
				$query_params[] = $clicks_how_many;
			}
			if ($ip_from_how_many!='' && $ip_from_how_many!='0') {
				$where_conditions[] = " ip_from_how_many = %d";
				$query_params[] = $ip_from_how_many;
			}
			
			
			if (count($where_conditions)!=0) {
				if ($not_condition==1) {
					$query .= ' where not (' . implode(' and ',$where_conditions) . ')';
				}
				else {
					$query .= ' where ' . implode(' and ',$where_conditions);
				}
			}
			
			// Return the Query and the parameters to pass to the Prepare query function
			return array($query,$query_params);
		}
		
		/**
		 * Return all items to show
		 * 
		 * @param	string	$link
		 * @param	int		$clicks_how_many
		 * @param	int		$ip_from_how_many
		 * 
		 * @param	string	$not_condition		if 1, will be applied a NOT to the conditions of the query
		 * 
		 * @param	array	$fields				if defined, list of fields to return
		 * 											, else all fields will be returned
		 * @param	int		$pagination_offset	if defined, the first row index to get
		 * @param	int		$rows				if defined, define how many rows to return
		 * 											, else all rows will be returned
		 * @param	int		$orderby			if defined, define the field to order by
		 * @param	int		$orderdir			if defined, define order direction
		 * 
		 * @return 	array						of DB filled AdvancedAA_User objects
		 */
		public function search($link,$clicks_how_many,$ip_from_how_many, $not_condition
										,$fields,$pagination_offset,$rows,$orderby,$orderdir) {
			global $wpdb;
									
			// Add common query
			$query_common_data = self::get_common_query($link,$clicks_how_many,$ip_from_how_many
										,$not_condition,$fields);
			$query = $query_common_data[0];
			
			// Pagination and Order
			if ($orderby!='') {
				$query .= " order by $orderby";
				if ($orderdir=='asc') { // Invert order for use of grid, only in this list of links
					$query .= " DESC";
				}
				else {
					$query .= " ASC";
				}
			}
			if ($rows!='') {
				$query .= " LIMIT $pagination_offset,$rows";
			}
			
			// Prepare and Execute query
			$query = $wpdb->prepare($query,$query_common_data[1]);
			$results = $wpdb->get_results($query);
			
			return $results;
		}
		
		/**
		 * Get the link details
		 * 
		 * @param	string	$link
		 * @return 	string
		 */
		public function get_details_by_link($link) {
			global $wpdb;
			
			$table = $this->get_db_table();
			
			// Initialize query, Set all fields to return
			$query = "select count( `id` ) as `clicks_how_many`,`ip_from` from `$table` where `link`='$link' group by `ip_from`";
			$result = $wpdb->get_results($query);
			
			$str_to_return = '';
			if (count($result)>0) {
				$str_to_return .= ' (';
				foreach ($result as $item) {
					$str_to_return .= " $item->clicks_how_many - IP $item->ip_from,";
				}
				$str_to_return = rtrim($str_to_return,','); // remove last comma
				$str_to_return .= ')';
			}
			
			return $str_to_return;
		}
		
		/**
		 * Get the amount of items that match the filters
		 * 
		 * @param	string	$link
		 * @param	int		$clicks_how_many
		 * @param	int		$ip_from_how_many
		 * 
		 * @param	string	$not_condition		if 1, will be applied a NOT to the conditions of the query
		 * 
		 * @param	array	$fields				if defined, list of fields to return
		 * 											, else all fields will be returned
		 * 
		 * @return 	int
		 */
		public function search_count($link,$clicks_how_many,$ip_from_how_many, $not_condition,$fields) {
			global $wpdb;
									
			// Add common query
			$query_common_data = self::get_common_query($link,$clicks_how_many,$ip_from_how_many
										,$not_condition); 
			$query = $query_common_data[0];
			// Prepare and Execute query
			$query = $wpdb->prepare($query,$query_common_data[1]);
			$result = $wpdb->get_results($query);
			
			return count($result);
		}
	}
}
