<?php
if (!class_exists('WPContentMagic_HtmlStyles')) {
	class WPContentMagic_HtmlStyles
	{
	    /**
         * Apply the bold HTML style
         * 
         * @param 	string	$text
         * @return 	string
         * @static 
         */
        static function apply_bold_style($text) {
        	
        	return '<strong>' . $text . '</strong>';
        }
        
	    /**
         * Apply the italic HTML style
         * 
         * @param 	string	$text
         * @return 	string
         * @static 
         */
        static function apply_italic_style($text) {
        	
        	return '<em>' . $text . '</em>';
        }
        
	    /**
         * Apply the underline HTML style
         * 
         * @param 	string	$text
         * @return 	string
         * @static 
         */
        static function apply_underline_style($text) {
        	
        	return '<u>' . $text . '</u>';
        }
        
	    /**
         * Add the link tag to the keyword
         * 
         * @param 	string	$key
         * @param 	string	$url
         * @param 	array	$settings
         * 
         * @return 	string
         * @static 
         */
        static function add_link($key,$url,$settings) {
        	
        	$link = '<a ';
        	
			if (($settings['cloak_links']=='1') || ($settings['track_links']=='1')) {
				$link .= 'onclick="javascript:';
				if ($settings['cloak_links']=='1') {
					$link .= "this.href='" . $url . "';";
				}
				if ($settings['track_links']=='1') {
					$link .= "jQuery.ajax({url:'";
					$link .= WPContentMagic::$plugin_url . "pages/ajax/track_link.php'";
        			$link .= ",cache:false, data:{url: '$url'},type: 'POST'";
        			$link .= ',});" ';
				}
			}
			
        	if ($settings['cloak_links']=='1') {
        		$cloaked_link = site_url() . '/go/' . urlencode($key);        		
        		$link .= 'href="' . $cloaked_link . '" ';
        	}
        	else {
        		// The href is the url
        		$link .= 'href="' . $url . '" ';
        	} 
        	
        	if ($settings['outbound_links_add_nofollow']=='1') {
        		$link .= 'rel="nofollow" ';
        	}
        	if ($settings['outbound_links_open_new_window']=='1') {
        		$link .= 'target="_blank" ';
        	}
        	
        	$link .= ">$key</a>";
        		
        	return $link;
        }
        
	    /**
         * Add the link html code to the token if the user set that in settings
         * 
         * Must be applied first than styles, in order to put the styles inside the keywords 
         * 
         * @param 	string	$post_content
         * @param 	array	$settings
         * @return 	string
         * @static 
         */
        static function apply_links_to_content($post_content,$settings) {
        	
        	if ($settings['add_hyperlinks']=='1') {
        		$how_many = $settings['in_content_hyperlinks_quantity'];
        		$keys_urls = explode(PHP_EOL,$settings['csv_keyword_url']);
        		$keys_arr = array();
        		$keys_url_arr = array();
        		foreach ($keys_urls as $keys_urls_str) {
        			$keys_urls_arr = explode(',',$keys_urls_str);
        			$keys_arr[] = trim($keys_urls_arr[0]);
        			$keys_url_arr[trim($keys_urls_arr[0])] = trim($keys_urls_arr[1]);
        		}
        		
	        	// If there isn't keywords, return the same Post Content
	        	if (count($keys_arr)==0) {
	        		return $post_content;
	        	}
        		
        		/*
	        	 * Pass through all keywords until: no more keyword, or no more link to apply
	        	 */
	        	$next_index_found = 0;
	        	$last_used_index = 0;
	        	$new_post_content = '';
	        	do {
	        		$next_key_arr = WPContentMagic_Keywords::search_next_keyword($post_content,$keys_arr,$next_index_found);
	        		$next_key_found = $next_key_arr[0];
	        		$next_index_found = $next_key_arr[1];
	        		
	        		if ($next_index_found!=='' && $how_many>0) {
		        		$new_post_content .= substr($post_content,$last_used_index,($next_index_found-$last_used_index));
		        		// Add hyperlink
		        		$new_post_content .= self::add_link($next_key_found,$keys_url_arr[$next_key_found],$settings);
		        		
		        		// Decrease counter
		        		$how_many--;
		        		
		        		$next_index_found += strlen($next_key_found);
		        		$last_used_index = $next_index_found;
	        		}
	        	}
	        	while($next_index_found!=='' && $how_many>0);
	        	
	        	// If don't find any more keyword or all styles were applied: complete the new content with the rest of content
	        	$new_post_content .= substr($post_content,$last_used_index);
        		
        		return $new_post_content;
        	}
        	else {
        		return $post_content;
        	}
        }
        
	    /**
         * Apply HTML styles to post content
         * 
         * @param 	string	$post_content
         * @param 	array	$keys_arr
         * @param 	array	$settings
         * @return 	string
         * @static 
         */
        static function apply_styles_to_content($post_content,$keys_arr,$settings) {
        	// If there isn't keywords, return the same Post Content
        	if (count($keys_arr)==0) {
        		return $post_content;
        	}
        	
        	/*
        	 * Define the queue of styles to apply
        	 */
        	$styles_queue = array();
        	if ($settings['seo_options_bold_decoration']=='1') {
        		for ($i=0;$i<$settings['seo_options_bold_per_article'];$i++) {
        			$styles_queue[] = 'bold';
        		}
        	}
        	if ($settings['seo_options_underline_decoration']=='1') {
        		for ($i=0;$i<$settings['seo_options_underline_per_article'];$i++) {
        			$styles_queue[] = 'underline';
        		}
        	}
        	if ($settings['seo_options_italicize_decoration']=='1') {
        		for ($i=0;$i<$settings['seo_options_italicize_per_article'];$i++) {
        			$styles_queue[] = 'italicize';
        		}
        	}
        	
        	/*
        	 * Pass through all keywords until: no more keyword, or no more style to apply
        	 */
        	$next_index_found = 0;
        	$last_used_index = 0;
        	$new_post_content = '';
        	do {
        		$next_key_arr = WPContentMagic_Keywords::search_next_keyword($post_content,$keys_arr,$next_index_found);
        		$next_key_found = $next_key_arr[0];
        		$next_index_found = $next_key_arr[1];
        		
        		if ($next_index_found!=='' && count($styles_queue)>0) {
	        		$new_post_content .= substr($post_content,$last_used_index,($next_index_found-$last_used_index));
	        		// Add keyword with style
	        		if ($styles_queue[0]=='bold') { // Always use the first in queue
	        			$new_post_content .= self::apply_bold_style($next_key_found);
	        		}
	        		elseif ($styles_queue[0]=='underline') { 
	        			$new_post_content .= self::apply_underline_style($next_key_found);
	        		}
	        		elseif ($styles_queue[0]=='italicize') { 
	        			$new_post_content .= self::apply_italic_style($next_key_found);
	        		}
	        		// Remove first element from array
	        		$styles_queue = array_slice($styles_queue,1);
	        		
	        		$next_index_found += strlen($next_key_found);
	        		$last_used_index = $next_index_found;
        		}
        	}
        	while($next_index_found!=='' && count($styles_queue)>0);
        	
        	// If don't find any more keyword or all styles were applied: complete the new content with the rest of content
        	$new_post_content .= substr($post_content,$last_used_index);
        	
        	return $new_post_content;
        }
	}
}
