<?php
if (!class_exists('WPContentMagic_Settings')) {
	class WPContentMagic_Settings 
	{
	   /**
	    * The name for plugin options in the DB
	    *
	    * @var string
	    */
        static $db_option = 'WPContentMagic_Options';
        
	   /**
	    * The name for plugin StopWords in the DB
	    *
	    * @var string
	    */
        static $db_option_stop_words = 'WPContentMagic_StopWords';
        
	   /**
		 * Get setting value
		 * 
		 * @static
		 * @param	string	$option_name
		 * @return 	string
		 * @access 	public
		 */
		static public function get_option_value($option_name) {
			$options = self::get_options();
		   	$to_return = trim($options[$option_name]);
		   	
		   	return $to_return;
		}
		
		/**
		 * Updates the General Settings of Plugin
		 * 
		 * @return void
		 * @access public
		 */
        static function update_options($options) {
	    	return update_option(self::$db_option, $options);	
	    }
        
		/**
		 * Update list of Stop words
		 * 
		 * @param 	string	$stop_words		separated by comma
		 * @access 	public
		 */
        static function update_stop_words($stop_words) {
        	update_option(self::$db_option_stop_words,$stop_words);
        }
        
		/**
		 * Get list of punctuations marks
		 * 
		 * @return array
		 * @access public
		 */
        static function get_punctuation_marks() {
        	return array('.',',','!','?',':',';');
        }
        
		/**
		 * Get list of characters to be ignored when detecting keywords in titles
		 * 
		 * @return array
		 * @access public
		 */
        static function get_characters_to_ignore() {
        	return array_merge(array('&','=','"','-',"'"),self::get_punctuation_marks());
        }
        
		/**
		 * Get list of characters allowed at the sides of keywords
		 * 
		 * @return array
		 * @access public
		 */
        static function get_characters_allowed_key_sides() {
        	return array_merge(array('>','<',' ',PHP_EOL),self::get_characters_to_ignore());
        }
        
		/**
		 * Get list of Stop words
		 * 
		 * @return array
		 * @access public
		 */
        static function get_stop_words() {
         	// get saved options
			$saved = get_option(self::$db_option_stop_words);
		    
			if ($saved===FALSE) {
				// assign default and return
		    	$default_value = self::get_default_stop_words();
		        add_option(self::$db_option_stop_words,join(',',$default_value));
		        return $default_value;
		    }
		    else {
		    	return explode(',',$saved);
		    }
        }
        
		/**
		 * Get list of Stop words
		 * 
		 * @return array
		 * @access public
		 */
        static function get_default_stop_words() {
	    	return array(
	    		'a','about','above','across','after','again','against','all','almost','alone','along','already'
	    		,'also','although','always','among','an','and','another','any','anybody','anyone','anything'
	    		,'anywhere','are','area','areas','around','as','ask','asked','asking','asks','at','away','b'
	    		,'back','backed','backing','backs','be','became','because','become','becomes','been','before'
	    		,'began','behind','being','beings','best','better','between','big','both','but','by','c','came'
	    		,'can','cannot','case','cases','certain','certainly','clear','clearly','come','could','d','did'
	    		,'differ','different','differently','do','does','done','down','down','downed','downing','downs'
	    		,'during','e','each','early','either','end','ended','ending','ends','enough','even','evenly','ever'
	    		,'every','everybody','everyone','everything','everywhere','f','face','faces','fact','facts','far'
	    		,'felt','few','find','finds','first','for','four','from','full','fully','further','furthered'
	    		,'furthering','furthers','g','gave','general','generally','get','gets','give','given','gives','go'
	    		,'going','good','goods','got','great','greater','greatest','group','grouped','grouping','groups','h'
	    		,'had','has','have','having','he','her','here','herself','high','high','high','higher','highest','him'
	    		,'himself','his','how','however','i','if','important','in','interest','interested','interesting'
	    		,'interests','into','is','it','its','itself','j','just','k','keep','keeps','kind','knew','know','known'
	    		,'knows','l','large','largely','last','later','latest','least','less','let','lets','like','likely'
	    		,'long','longer','longest','m','made','make','making','man','many','may','me','member','members','men'
	    		,'might','more','most','mostly','mr','mrs','much','must','my','myself','n','necessary','need','needed'
	    		,'needing','needs','never','new','new','newer','newest','next','no','nobody','non','noone','not'
	    		,'nothing','now','nowhere','number','numbers','o','of','off','often','old','older','oldest','on'
	    		,'once','one','only','open','opened','opening','opens','or','order','ordered','ordering','orders'
	    		,'other','others','our','out','over','p','part','parted','parting','parts','per','perhaps','place'
	    		,'places','point','pointed','pointing','points','possible','present','presented','presenting','presents'
	    		,'problem','problems','put','puts','q','quite','r','rather','really','right','right','room','rooms'
	    		,'s','said','same','saw','say','says','second','seconds','see','seem','seemed','seeming','seems'
	    		,'sees','several','shall','she','should','show','showed','showing','shows','side','sides','since'
	    		,'small','smaller','smallest','so','some','somebody','someone','something','somewhere','state','states'
	    		,'still','still','such','sure','t','take','taken','than','that','the','their','them','then','there'
	    		,'therefore','these','they','thing','things','think','thinks','this','those','though','thought'
	    		,'thoughts','three','through','thus','to','today','together','too','took','toward','turn','turned'
	    		,'turning','turns','two','u','under','until','up','upon','us','use','used','uses','v','very','w'
	    		,'want','wanted','wanting','wants','was','way','ways','we','well','wells','went','were','what','when'
	    		,'where','whether','which','while','who','whole','whose','why','will','with','within','without','work'
	    		,'worked','working','works','would','x','y','year','years','yet','you','young','younger','youngest'
	    		,'your','yours','z'
	    		);
	    }
        
    	/**
		 * Return the General Settings of Plugin, and set them to default values if they are empty
		 * 
		 * @return array general options of plugin
		 * @access public
		 */
        static function get_options() {
        	// default values
		    $options = array 
		    (
		        'post_type' => 'post'
		        ,'post_status' => 'publish'
		        ,'post_title_from' => 'file'
		        ,'auto_tag_article' => '1'	// 1: Yes, 0: No, 2: use the keys typed by users
		        ,'keywords_typed_for_tag_article' => ''
		        
		        ,'post_category' => '1'	// Uncatecorized
		        
		        ,'auto_posting_schedule' => 'now'
		        ,'custom_schedule_date' => ''
		        ,'schedule_number_begin' => '3'
		        ,'schedule_unit_begin' => 'minutes'
		        ,'schedule_number_end' => '3'
		        ,'schedule_unit_end' => 'hours'
		        
		        ,'seo_options_bold_decoration' => '1'
		        ,'seo_options_bold_per_article' => '1'
		        ,'seo_options_underline_decoration' => '1'
		        ,'seo_options_underline_per_article' => '1'
		        ,'seo_options_italicize_decoration' => '1'
		        ,'seo_options_italicize_per_article' => '1'

		        ,'add_hyperlinks' => '0'
		        ,'in_content_hyperlinks_quantity' => '1'
		        ,'csv_keyword_url' => ''
		        
		        ,'cloak_links' => '1'
		        ,'track_links' => '1'
		        ,'outbound_links_add_nofollow' => '1'
		        ,'outbound_links_open_new_window' => '1'
		        
		    );
		    
		    // get saved options
			$saved = get_option(self::$db_option);
		    
			// assign them
		    if (!empty($saved)) {
		        foreach ($saved as $key => $option) {
		        	$options[$key] = WPContentMagic_Validator::parse_output($option);
		        }
		    }
		    
		    // update the options if necessary
	        if ($saved != $options)
	        	update_option(self::$db_option, $options);
	        //return the options
	        return $options;
        }
	}
}
