<?php
/**
 * Page to handle all Ajax requests for list data.
 * All data will be returned using JSON format
 * 
 * General variables:
 * 
 * @uses	$_REQUEST['object']
 * @uses	$_REQUEST['fields']			array with all the fields names that must be returned, if empty returns all fields
 * 
 * @uses	$_REQUEST['not_condition']	if defined, will be applied a NOT to the conditions of the query
 * 
 * @uses	$_REQUEST['page']			paginations variable to determine which page to show
 * @uses	$_REQUEST['rows']			paginations variable to determine how many items show in that page
 * 
 * @uses	$_REQUEST['orderby']		order variable to determine the field to order by it. 
 * 											Must be one of the values in Fields array or any available for object if Fields is empty
 * @uses	$_REQUEST['orderdir']		order variable to determine the direction of the order, can be: asc or desc
 * 
 * @example of receiving data
 * 		$_REQUEST['object'] = 'scheduled_posts';
		$_REQUEST['page'] = 1;
		$_REQUEST['rows'] = 2;
		$_REQUEST['orderby'] = 'schedule_datetime';
		$_REQUEST['orderdir'] = 'desc';
 */	

/** Loads the WordPress Environment */
require(dirname(__FILE__) . '/../../../../../wp-load.php');

// Set the list of fields to return
if (isset($_REQUEST['fields']))	$fields = (array) $_REQUEST['fields'];
else $fields = array(); // Equivalent to all fields

// Set the variable not_condition
if (isset($_REQUEST['not_condition'])) $not_condition = 1;
else $not_condition = 0;

// Set pagination variables
if (isset($_REQUEST['page'])) $page = $_REQUEST['page'];
else $page = 1;
if ($page<1) $page = 1; // Validate for non allowed values of page
if (isset($_REQUEST['rows'])) $rows = $_REQUEST['rows'];
else $rows = ''; // Means all rows

if ($rows=='') {
	$pagination_offset = 0;
}
else {
	$pagination_offset = (($page - 1)*$rows) + 1; // This is the number, beggining by 1
	$pagination_offset--;// But Mysql begins counting by 0
}

// Set order variables
if (isset($_REQUEST['orderby'])) $orderby = $_REQUEST['orderby'];
else $orderby = '';
if (isset($_REQUEST['orderdir'])) $orderdir = $_REQUEST['orderdir'];
else $orderdir = '';

/**
 * List clicks per links
 * 
 * @uses	$_REQUEST['link']
 * @uses	$_REQUEST['clicks_how_many']
 * @uses	$_REQUEST['ip_from_how_many']
 * 
 * Condition
 * - $_REQUEST['object']=='clicks_links'
 * 
 */

if ($_REQUEST['object']=='clicks_links') {

	// Set values for filters. For password don't filter ;)
	if (isset($_REQUEST['link'])) $link = $_REQUEST['link'];
	else $link = '';
	if (isset($_REQUEST['clicks_how_many'])) $clicks_how_many = $_REQUEST['clicks_how_many'];
	else $clicks_how_many = '';
	if (isset($_REQUEST['ip_from_how_many'])) $ip_from_how_many = $_REQUEST['ip_from_how_many'];
	else $ip_from_how_many = '';
	
	// Make request and fill data to return
	$clicks_links = new WPContentMagic_ClicksLinks();
	$list = $clicks_links->search($link,$clicks_how_many,$ip_from_how_many, $not_condition
										,$fields,$pagination_offset,$rows,$orderby,$orderdir);
	
	// Get total of rows to calculate the total numbers of pages of the Grid
	$total_rows = $clicks_links->search_count($link,$clicks_how_many,$ip_from_how_many, $not_condition,$fields);
	
	$data_to_return['rows'] = array();
	foreach ($list as $obj) {
		$data_item = array();
		
		$data_item['id'] = (string) $obj->id;
		
		$data_item['cell'][] = (string) $obj->link;
		$data_item['cell'][] = (string) $obj->clicks_how_many;
		// Add details
		$links_details = $clicks_links->get_details_by_link($obj->link);
		$data_item['cell'][] = ((string) $obj->ip_from_how_many) . $links_details;
		
		// Add item to list
		$data_to_return['rows'][] = $data_item;
	}
}

/**
 * Return data
 * 
 * @return	$data_to_return	if JSON format
 * @example $data_to_return = array(
	"total" => "12", 	
	"page" => "2",		
	"records" => "24",	
	"rows"  => array(		
				array("id" => "1", "cell" => ("desc1","complete")),
				array("id" => "2", "cell" => ("desc2","waiting to start")), 
				array("id" => "3", "cell" => ("desc3","freezed")),
			),
		);
 */
if (isset($data_to_return)) {
	// Define data to return
	$data_to_return['page'] = $page; 	// Used by JS Grid: Current page, the same the JS sent me
	// Calculate the total numbers of pages of the Grid, using the $rows general data and the total of rows $total_rows
	if ($rows=='') { // This means all rows will be showed
		$data_to_return['total'] = 1;
	}
	else {
		$data_to_return['total'] = ceil($total_rows / $rows);
	}
	$data_to_return['records'] = $total_rows;
	
	$json = json_encode($data_to_return);
	echo $json;
}




